@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -89,7 +89,7 @@ class AuthenticationView(APIView):
         return {
             'ok': True,
             'user': self.get_user_info(user),
-            'permissions': list(auth.cache_permissions(Session(), user)),
+            'permissions': list(auth.get_permissions(Session(), user)),
         }
 
     def authenticate_user(self, username, password):
