@@ -27,7 +27,6 @@ Forms Core
 from __future__ import unicode_literals, absolute_import
 
 import json
-import datetime
 import logging
 
 import six
@@ -36,7 +35,7 @@ from sqlalchemy import orm
 from sqlalchemy.ext.associationproxy import AssociationProxy, ASSOCIATION_PROXY
 
 from rattail.time import localtime
-from rattail.util import prettify, pretty_boolean, pretty_hours, pretty_quantity
+from rattail.util import prettify, pretty_boolean, pretty_quantity
 from rattail.core import UNSPECIFIED
 
 import colander
@@ -112,22 +111,14 @@ class CustomSchemaNode(SQLAlchemySchemaNode):
         for the given association proxy field name.  Typically this will refer
         to the "extension" model class.
         """
-        proxy = self.association_proxy(field)
-        if proxy:
-            proxy_target = self.inspector.get_property(proxy.target_collection)
-            if isinstance(proxy_target, orm.RelationshipProperty) and not proxy_target.uselist:
-                return proxy_target
+        return get_association_proxy_target(self.inspector, field)
 
     def association_proxy_column(self, field):
         """
         Returns the property on the proxy target class, for the column which is
         reflected by the proxy.
         """
-        proxy_target = self.association_proxy_target(field)
-        if proxy_target:
-            prop = proxy_target.mapper.get_property(field)
-            if isinstance(prop, orm.ColumnProperty) and isinstance(prop.columns[0], sa.Column):
-                return prop
+        return get_association_proxy_column(self.inspector, field)
 
     def supported_association_proxy(self, field):
         """
@@ -683,10 +674,18 @@ class Form(object):
            case the validator pertains to the form at large instead of
            one of the fields.
 
+           TODO: what should the validator look like?
+
         :param validator: Callable validator for the node.
         """
         self.validators[key] = validator
 
+        # we normally apply the validator when creating the schema, so
+        # if this form already has a schema, then go ahead and apply
+        # the validator to it
+        if self.schema and key in self.schema:
+            self.schema[key].validator = validator
+
     def set_required(self, key, required=True):
         """
         Set whether or not value is required for a given field.
@@ -902,10 +901,11 @@ class Form(object):
         return raw_datetime(self.request.rattail_config, value)
 
     def render_duration(self, record, field_name):
-        value = self.obtain_value(record, field_name)
-        if value is None:
+        seconds = self.obtain_value(record, field_name)
+        if seconds is None:
             return ""
-        return pretty_hours(datetime.timedelta(seconds=value))
+        app = self.request.rattail_config.get_app()
+        return app.render_duration(seconds=seconds)
 
     def render_boolean(self, record, field_name):
         value = self.obtain_value(record, field_name)
