@@ -251,6 +251,9 @@ class JQueryAutocompleteWidget(dfwidget.AutocompleteInputWidget):
     service_url = None
     cleared_callback = None
     selected_callback = None
+    input_callback = None
+    new_label_callback = None
+    ref = None
 
     default_options = (
         ('autoFocus', True),
@@ -277,6 +280,9 @@ class JQueryAutocompleteWidget(dfwidget.AutocompleteInputWidget):
         kw['field_display'] = self.field_display
         kw['cleared_callback'] = self.cleared_callback
         kw['assigned_label'] = self.assigned_label
+        kw['input_callback'] = self.input_callback
+        kw['new_label_callback'] = self.new_label_callback
+        kw['ref'] = self.ref
         kw.setdefault('selected_callback', self.selected_callback)
         tmpl_values = self.get_template_values(field, cstruct, kw)
         template = readonly and self.readonly_template or self.template
