@@ -26,7 +26,6 @@ Core Grid Classes
 
 from __future__ import unicode_literals, absolute_import
 
-import datetime
 import warnings
 import logging
 
@@ -77,10 +76,11 @@ class Grid(object):
                  enums={}, labels={}, assume_local_times=False, renderers={}, invisible=[],
                  extra_row_class=None, linked_columns=[], url='#',
                  joiners={}, filterable=False, filters={}, use_byte_string_filters=False,
+                 searchable={},
                  sortable=False, sorters={}, default_sortkey=None, default_sortdir='asc',
                  pageable=False, default_pagesize=20, default_page=1,
                  checkboxes=False, checked=None, check_handler=None, check_all_handler=None,
-                 clicking_row_checks_box=False,
+                 clicking_row_checks_box=False, click_handlers=None,
                  main_actions=[], more_actions=[], delete_speedbump=False,
                  ajax_data_url=None, component='tailbone-grid',
                  **kwargs):
@@ -120,6 +120,8 @@ class Grid(object):
         self.use_byte_string_filters = use_byte_string_filters
         self.filters = self.make_filters(filters)
 
+        self.searchable = searchable or {}
+
         self.sortable = sortable
         self.sorters = self.make_sorters(sorters)
         self.default_sortkey = default_sortkey
@@ -137,6 +139,8 @@ class Grid(object):
         self.check_all_handler = check_all_handler
         self.clicking_row_checks_box = clicking_row_checks_box
 
+        self.click_handlers = click_handlers or {}
+
         self.main_actions = main_actions or []
         self.more_actions = more_actions or []
         self.delete_speedbump = delete_speedbump
@@ -240,6 +244,15 @@ class Grid(object):
                 kwargs['label'] = self.labels[key]
             self.filters[key] = self.make_filter(key, *args, **kwargs)
 
+    def set_searchable(self, key, searchable=True):
+        if searchable:
+            self.searchable[key] = True
+        else:
+            self.searchable.pop(key, None)
+
+    def is_searchable(self, key):
+        return self.searchable.get(key, False)
+
     def remove_filter(self, key):
         self.filters.pop(key, None)
 
@@ -262,6 +275,15 @@ class Grid(object):
             if self.linked_columns and key in self.linked_columns:
                 self.linked_columns.remove(key)
 
+    def set_click_handler(self, key, handler):
+        if handler:
+            self.click_handlers[key] = handler
+        else:
+            self.click_handlers.pop(key, None)
+
+    def has_click_handler(self, key):
+        return key in self.click_handlers
+
     def set_renderer(self, key, renderer):
         self.renderers[key] = renderer
 
@@ -358,10 +380,11 @@ class Grid(object):
         return pretty_quantity(value)
 
     def render_duration(self, obj, column_name):
-        value = self.obtain_value(obj, column_name)
-        if value is None:
+        seconds = self.obtain_value(obj, column_name)
+        if seconds is None:
             return ""
-        return pretty_hours(datetime.timedelta(seconds=value))
+        app = self.request.rattail_config.get_app()
+        return app.render_duration(seconds=seconds)
 
     def render_duration_hours(self, obj, field):
         value = self.obtain_value(obj, field)
