@@ -22,7 +22,13 @@ let FeedbackForm = {
             }
 
             this.submitForm(this.action, params, response => {
-                alert("Message successfully sent.\n\nThank you for your feedback.")
+
+                this.$buefy.toast.open({
+                    message: "Message sent!  Thank you for your feedback.",
+                    type: 'is-info',
+                    duration: 4000, // 4 seconds
+                })
+
                 this.showDialog = false
                 // clear out message, in case they need to send another
                 this.message = ""
