@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -251,3 +251,24 @@ def route_exists(request, route_name):
     mapper = reg.getUtility(IRoutesMapper)
     route = mapper.get_route(route_name)
     return bool(route)
+
+
+def include_configured_views(pyramid_config):
+    """
+    Include arbitrary additional views based on DB settings.
+    """
+    rattail_config = pyramid_config.registry.settings.get('rattail_config')
+    app = rattail_config.get_app()
+    model = rattail_config.get_model()
+    session = app.make_session()
+
+    # fetch all include-related settings at once
+    settings = session.query(model.Setting)\
+                      .filter(model.Setting.name.like('tailbone.includes.%'))\
+                      .all()
+
+    for setting in settings:
+        if setting.value:
+            pyramid_config.include(setting.value)
+
+    session.close()
