@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -29,9 +29,6 @@ from __future__ import unicode_literals, absolute_import
 from .core import View
 from .master import MasterView
 
-# TODO: deprecate / remove some of this
-from .autocomplete import AutocompleteView
-
 
 def includeme(config):
 
