@@ -131,12 +131,20 @@ class CustomerView(MasterView):
         g.set_sorter('person', model.Person.display_name)
         g.set_renderer('person', self.grid_render_person)
 
+        # active_in_pos
+        g.filters['active_in_pos'].default_active = True
+        g.filters['active_in_pos'].default_verb = 'is_true'
+
         g.set_link('id')
         g.set_link('number')
         g.set_link('name')
         g.set_link('person')
         g.set_link('email')
 
+    def grid_extra_class(self, customer, i):
+        if not customer.active_in_pos:
+            return 'warning'
+
     def get_instance(self):
         try:
             instance = super(CustomerView, self).get_instance()
@@ -606,12 +614,23 @@ def customer_info(request):
         }
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
 
-    # info
+    # TODO: deprecate / remove this
     config.add_route('customer.info', '/customers/info')
+    customer_info = kwargs.get('customer_info', base['customer_info'])
     config.add_view(customer_info, route_name='customer.info',
                     renderer='json', permission='customers.view')
 
+    CustomerView = kwargs.get('CustomerView',
+                              base['CustomerView'])
     CustomerView.defaults(config)
+
+    PendingCustomerView = kwargs.get('PendingCustomerView',
+                                     base['PendingCustomerView'])
     PendingCustomerView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
