@@ -105,6 +105,9 @@ class EmailSettingView(MasterView):
         g.set_link('key')
         g.set_link('subject')
 
+        g.set_searchable('key')
+        g.set_searchable('subject')
+
         # to
         g.set_renderer('to', self.render_to_short)
         g.sorters['to'] = g.make_simple_sorter('to', foldcase=True)
