@@ -329,5 +329,12 @@ class EmployeeView(MasterView):
                                        "View *all* (not just current) {}".format(model_title_plural))
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    EmployeeView = kwargs.get('EmployeeView', base['EmployeeView'])
     EmployeeView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
