@@ -167,7 +167,7 @@ class ImportingView(MasterView):
         """
         key = self.request.matchdict['key']
         app = self.get_rattail_app()
-        handler = app.get_designated_import_handler(key, ignore_errors=True)
+        handler = app.get_import_handler(key, ignore_errors=True)
         if handler:
             return self.normalize(handler)
         raise self.notfound()
@@ -467,8 +467,6 @@ And here is the output:
                 '--config={}/app/quiet.conf'.format(sys.prefix),
                 '--progress',
                 '--progress-socket=127.0.0.1:{}'.format(port),
-                '--runas={}'.format(runas),
-                subcommand,
             ]
         else:
             cmd = [
@@ -476,10 +474,16 @@ And here is the output:
                 'bin/{}'.format(command),
                 '-c', 'app/quiet.conf',
                 '-P',
-                '--runas', runas,
-                subcommand,
             ]
 
+        if runas:
+            if typ == 'true':
+                cmd.append('--runas={}'.format(runas))
+            else:
+                cmd.extend(['--runas', runas])
+
+        cmd.append(subcommand)
+
         cmd.extend(data['models'])
 
         if data['create']:
@@ -556,7 +560,7 @@ cd {prefix}
     def configure_gather_settings(self, data):
         settings = []
 
-        for handler in data['handlers']:
+        for handler in json.loads(data['handlers']):
             key = handler['key']
 
             settings.extend([
