@@ -159,6 +159,8 @@ class ReceivingBatchView(PurchasingBatchView):
         'description',
         'size',
         'department_name',
+        'cases_ordered',
+        'units_ordered',
         'cases_shipped',
         'units_shipped',
         'cases_received',
@@ -672,6 +674,7 @@ class ReceivingBatchView(PurchasingBatchView):
         for key, label in labels.items():
             if key in grouped:
                 breakdown.append({
+                    'key': key,
                     'title': label,
                     'count': len(grouped[key]),
                 })
@@ -681,15 +684,26 @@ class ReceivingBatchView(PurchasingBatchView):
     def template_kwargs_view(self, **kwargs):
         kwargs = super(ReceivingBatchView, self).template_kwargs_view(**kwargs)
         batch = kwargs['instance']
+        use_buefy = self.get_use_buefy()
 
         if self.handler.has_purchase_order(batch) and self.handler.has_invoice_file(batch):
             breakdown = self.make_po_vs_invoice_breakdown(batch)
-
             factory = self.get_grid_factory()
-            kwargs['po_vs_invoice_breakdown_grid'] = factory(
-                'batch_po_vs_invoice_breakdown',
-                data=breakdown,
-                columns=['title', 'count'])
+            if use_buefy:
+
+                g = factory('batch_po_vs_invoice_breakdown', [],
+                    columns=['title', 'count'])
+                g.set_click_handler('title', "autoFilterPoVsInvoice(props.row)")
+                kwargs['po_vs_invoice_breakdown_data'] = breakdown
+                kwargs['po_vs_invoice_breakdown_grid'] = HTML.literal(
+                    g.render_buefy_table_element(data_prop='poVsInvoiceBreakdownData',
+                                                 empty_labels=True))
+
+            else:
+                kwargs['po_vs_invoice_breakdown_grid'] = factory(
+                    'batch_po_vs_invoice_breakdown',
+                    data=breakdown,
+                    columns=['title', 'count'])
 
         return kwargs
 
@@ -904,6 +918,20 @@ class ReceivingBatchView(PurchasingBatchView):
         g.set_joiner('credits', lambda q: q.outerjoin(Credits))
         g.sorters['credits'] = lambda q, d: q.order_by(getattr(Credits.c.credit_count, d)())
 
+        show_ordered = self.rattail_config.getbool(
+            'rattail.batch', 'purchase.receiving.show_ordered_column_in_grid',
+            default=False)
+        if not show_ordered:
+            g.remove('cases_ordered',
+                     'units_ordered')
+
+        show_shipped = self.rattail_config.getbool(
+            'rattail.batch', 'purchase.receiving.show_shipped_column_in_grid',
+            default=False)
+        if not show_shipped:
+            g.remove('cases_shipped',
+                     'units_shipped')
+
         # hide 'ordered' columns for truck dump parent, if its "children first"
         # flag is set, since that batch type is only concerned with receiving
         if batch.is_truck_dump_parent() and not batch.truck_dump_children_first:
@@ -1851,6 +1879,14 @@ class ReceivingBatchView(PurchasingBatchView):
              'option': 'purchase.allow_truck_dump_receiving',
              'type': bool},
 
+            # display
+            {'section': 'rattail.batch',
+             'option': 'purchase.receiving.show_ordered_column_in_grid',
+             'type': bool},
+            {'section': 'rattail.batch',
+             'option': 'purchase.receiving.show_shipped_column_in_grid',
+             'type': bool},
+
             # product handling
             {'section': 'rattail.batch',
              'option': 'purchase.allow_cases',
