@@ -214,6 +214,7 @@ class ReportOutputView(ExportMasterView):
     url_prefix = '/reports/generated'
     creatable = True
     downloadable = True
+    bulk_deletable = True
     configurable = True
     config_title = "Reporting"
     config_url = '/reports/configure'
@@ -246,14 +247,38 @@ class ReportOutputView(ExportMasterView):
 
     def configure_grid(self, g):
         super(ReportOutputView, self).configure_grid(g)
+
+        g.filters['report_name'].default_active = True
+        g.filters['report_name'].default_verb = 'contains'
+
         g.set_link('filename')
 
     def configure_form(self, f):
         super(ReportOutputView, self).configure_form(f)
 
+        # report_type
+        f.set_renderer('report_type', self.render_report_type)
+
         # params
         f.set_renderer('params', self.render_params)
 
+    def render_report_type(self, output, field):
+        type_key = getattr(output, field)
+
+        # (try to) show link to poser report if applicable
+        if type_key and type_key.startswith('poser_'):
+            app = self.get_rattail_app()
+            poser_handler = app.get_poser_handler()
+            poser_key = type_key[6:]
+            report = poser_handler.normalize_report(poser_key)
+            if not report.get('error'):
+                url = self.request.route_url('poser_reports.view',
+                                             report_key=poser_key)
+                return tags.link_to(type_key, url)
+
+        # fallback to showing value as-is
+        return type_key
+
     def render_params(self, report, field):
         params = report.params
         if not params:
@@ -400,7 +425,8 @@ class ReportOutputView(ExportMasterView):
         form = forms.Form(schema=schema, request=self.request,
                           use_buefy=use_buefy, helptext=helptext)
         form.submit_label = "Generate this Report"
-        form.cancel_url = self.request.route_url('{}.create'.format(route_prefix))
+        form.cancel_url = self.request.get_referrer(
+            default=self.request.route_url('{}.create'.format(route_prefix)))
 
         # must declare jquery support for date fields, ugh
         # TODO: obviously would be nice for this to be automatic?
@@ -644,7 +670,7 @@ class ProblemReportView(MasterView):
 
     def execute_instance(self, report_info, user, progress=None, **kwargs):
         report = report_info['_report']
-        problems = self.handler.run_problem_report(report)
+        problems = self.handler.run_problem_report(report, progress=progress)
         return "Report found {} problems".format(len(problems))
 
 
