@@ -30,6 +30,8 @@ import six
 
 from rattail.time import localtime
 
+from webhelpers2.html import HTML
+
 from tailbone.db import Session, TrainwreckSession, ExtraTrainwreckSessions
 from tailbone.views import MasterView
 
@@ -94,6 +96,9 @@ class TransactionView(MasterView):
         'tax',
         'cashback',
         'total',
+        'patronage',
+        'equity_current',
+        'self_updated',
         'void',
     ]
 
@@ -133,9 +138,13 @@ class TransactionView(MasterView):
         'description',
         'unit_quantity',
         'subtotal',
+        'discounts',
+        'discounted_subtotal',
         'tax',
         'total',
         'exempt_from_gross_sales',
+        'net_sales',
+        'gross_sales',
         'void',
     ]
 
@@ -156,6 +165,7 @@ class TransactionView(MasterView):
 
         g.set_enum('system', self.enum.TRAINWRECK_SYSTEM)
         g.set_type('total', 'currency')
+        g.set_type('patronage', 'currency')
         g.set_label('terminal_id', "Terminal")
         g.set_label('receipt_number', "Receipt No.")
         g.set_label('customer_id', "Customer ID")
@@ -184,6 +194,7 @@ class TransactionView(MasterView):
         f.set_type('tax', 'currency')
         f.set_type('cashback', 'currency')
         f.set_type('total', 'currency')
+        f.set_type('patronage', 'currency')
 
         # label overrides
         f.set_label('system_id', "System ID")
@@ -209,6 +220,9 @@ class TransactionView(MasterView):
         g.set_type('tax', 'currency')
         g.set_type('total', 'currency')
 
+        g.set_link('item_scancode')
+        g.set_link('description')
+
     def row_grid_extra_class(self, row, i):
         if row.void:
             return 'warning'
@@ -226,6 +240,50 @@ class TransactionView(MasterView):
         f.set_type('tax', 'currency')
         f.set_type('total', 'currency')
 
+        # discounts
+        f.set_renderer('discounts', self.render_discounts)
+
+    def render_discounts(self, item, field):
+        if not item.discounts:
+            return
+
+        route_prefix = self.get_route_prefix()
+        factory = self.get_grid_factory()
+        use_buefy = self.get_use_buefy()
+
+        g = factory(
+            key='{}.discounts'.format(route_prefix),
+            data=[] if use_buefy else item.discounts,
+            columns=['discount_type', 'description', 'amount'],
+            labels={'discount_type': "Type"},
+            request=self.request)
+
+        if use_buefy:
+            return HTML.literal(
+                g.render_buefy_table_element(data_prop='discountsData'))
+        else:
+            g.set_type('amount', 'currency')
+            return HTML.literal(g.render_grid())
+
+    def template_kwargs_view_row(self, **kwargs):
+        use_buefy = self.get_use_buefy()
+        if use_buefy:
+            form = kwargs['form']
+            if 'discounts' in form:
+
+                app = self.get_rattail_app()
+                item = kwargs['instance']
+                discounts_data = []
+                for discount in item.discounts:
+                    discounts_data.append({
+                        'discount_type': discount.discount_type,
+                        'description': discount.description,
+                        'amount': app.render_currency(discount.amount),
+                    })
+                kwargs['discounts_data'] = discounts_data
+
+        return kwargs
+
     def rollover(self):
         """
         View for performing yearly rollover functions.
