@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,12 +26,10 @@ User Views
 
 from __future__ import unicode_literals, absolute_import
 
-import copy
-
 import six
 from sqlalchemy import orm
 
-from rattail.db import model
+from rattail.db.model import User, UserEvent
 from rattail.db.auth import (administrator_role, guest_role,
                              authenticated_role, set_user_password)
 
@@ -40,8 +38,7 @@ from deform import widget as dfwidget
 from webhelpers2.html import HTML, tags
 
 from tailbone import forms
-from tailbone.db import Session
-from tailbone.views import MasterView
+from tailbone.views import MasterView, View
 from tailbone.views.principal import PrincipalMasterView, PermissionsRenderer
 
 
@@ -49,9 +46,9 @@ class UserView(PrincipalMasterView):
     """
     Master view for the User model.
     """
-    model_class = model.User
+    model_class = User
     has_rows = True
-    model_row_class = model.UserEvent
+    model_row_class = UserEvent
     has_versions = True
     touchable = True
 
@@ -99,6 +96,7 @@ class UserView(PrincipalMasterView):
 
     def query(self, session):
         query = super(UserView, self).query(session)
+        model = self.model
 
         # bring in the related Person(s)
         query = query.outerjoin(model.Person)\
@@ -108,6 +106,7 @@ class UserView(PrincipalMasterView):
 
     def configure_grid(self, g):
         super(UserView, self).configure_grid(g)
+        model = self.model
 
         del g.filters['salt']
         g.filters['username'].default_active = True
@@ -135,6 +134,10 @@ class UserView(PrincipalMasterView):
         g.set_link('last_name')
         g.set_link('display_name')
 
+    def grid_extra_class(self, user, i):
+        if not user.active:
+            return 'warning'
+
     def editable_instance(self, user):
         """
         If the given user is "protected" then we only allow edit if current
@@ -156,6 +159,7 @@ class UserView(PrincipalMasterView):
         return not self.user_is_protected(user)
 
     def unique_username(self, node, value):
+        model = self.model
         query = self.Session.query(model.User)\
                             .filter(model.User.username == value)
         if self.editing:
@@ -177,6 +181,7 @@ class UserView(PrincipalMasterView):
 
     def configure_form(self, f):
         super(UserView, self).configure_form(f)
+        model = self.model
         user = f.model_instance
 
         # username
@@ -261,6 +266,7 @@ class UserView(PrincipalMasterView):
             f.remove('set_password')
 
     def get_possible_roles(self):
+        model = self.model
 
         # some roles should never have users "belong" to them
         excluded = [
@@ -277,6 +283,7 @@ class UserView(PrincipalMasterView):
                            .order_by(model.Role.name)
 
     def objectify(self, form, data=None):
+        model = self.model
 
         # create/update user as per normal
         if data is None:
@@ -324,6 +331,7 @@ class UserView(PrincipalMasterView):
         if 'roles' not in data:
             return
 
+        model = self.model
         old_roles = set([r.uuid for r in user.roles])
         new_roles = data['roles']
         admin = administrator_role(self.Session())
@@ -385,6 +393,7 @@ class UserView(PrincipalMasterView):
         return HTML.tag('ul', c=items)
 
     def get_row_data(self, user):
+        model = self.model
         return self.Session.query(model.UserEvent)\
                            .filter(model.UserEvent.user == user)
 
@@ -398,6 +407,7 @@ class UserView(PrincipalMasterView):
         g.main_actions = []
 
     def get_version_child_classes(self):
+        model = self.model
         return [
             (model.UserRole, 'user_uuid'),
         ]
@@ -405,6 +415,7 @@ class UserView(PrincipalMasterView):
     def find_principals_with_permission(self, session, permission):
         app = self.get_rattail_app()
         auth = app.get_auth_handler()
+        model = self.model
 
         # TODO: this should search Permission table instead, and work backward to User?
         all_users = session.query(model.User)\
@@ -444,6 +455,105 @@ class UserView(PrincipalMasterView):
         assert not removing._roles
         self.Session.delete(removing)
 
+    def preferences(self, user=None):
+        """
+        View to modify preferences for a particular user.
+        """
+        current_user = True
+        if not user:
+            current_user = False
+            user = self.get_instance()
+
+        # TODO: this is of course largely copy/pasted from the
+        # MasterView.configure() method..should refactor?
+        if self.request.method == 'POST':
+            if self.request.POST.get('remove_settings'):
+                self.preferences_remove_settings(user)
+                self.request.session.flash("Settings have been removed.")
+                return self.redirect(self.request.current_route_url())
+            else:
+                data = self.request.POST
+
+                # then gather/save settings
+                settings = self.preferences_gather_settings(data, user)
+                self.preferences_remove_settings(user)
+                self.configure_save_settings(settings)
+                self.request.session.flash("Settings have been saved.")
+                return self.redirect(self.request.current_route_url())
+
+        context = self.preferences_get_context(user, current_user)
+        return self.render_to_response('preferences', context)
+
+    def my_preferences(self):
+        """
+        View to modify preferences for the current user.
+        """
+        user = self.request.user
+        if not user:
+            raise self.forbidden()
+        return self.preferences(user=user)
+
+    def preferences_get_context(self, user, current_user):
+        simple_settings = self.preferences_get_simple_settings(user)
+        context = self.configure_get_context(simple_settings=simple_settings,
+                                             input_file_templates=False)
+
+        instance_title = self.get_instance_title(user)
+        context.update({
+            'user': user,
+            'instance': user,
+            'instance_title': instance_title,
+            'instance_url': self.get_action_url('view', user),
+            'config_title': instance_title,
+            'config_preferences': True,
+            'current_user': current_user,
+        })
+
+        if current_user:
+            context.update({
+                'index_url': None,
+                'index_title': instance_title,
+            })
+
+        # theme style options
+        options = [{'value': None, 'label': "default"}]
+        styles = self.rattail_config.getlist('tailbone', 'themes.styles',
+                                             default=[])
+        for name in styles:
+            css = self.rattail_config.get('tailbone',
+                                          'themes.style.{}'.format(name))
+            if css:
+                options.append({'value': css, 'label': name})
+        context['buefy_css_options'] = options
+
+        return context
+
+    def preferences_get_simple_settings(self, user):
+        """
+        This method is conceptually the same as for
+        :meth:`~tailbone.views.master.MasterView.configure_get_simple_settings()`.
+        See its docs for more info.
+
+        The only difference here is that we are given a user account,
+        so the settings involved should only pertain to that user.
+        """
+        return [
+
+            # display
+            {'section': 'tailbone.{}'.format(user.uuid),
+             'option': 'buefy_css'},
+        ]
+
+    def preferences_gather_settings(self, data, user):
+        simple_settings = self.preferences_get_simple_settings(user)
+        return self.configure_gather_settings(
+            data, simple_settings=simple_settings, input_file_templates=False)
+
+    def preferences_remove_settings(self, user):
+        simple_settings = self.preferences_get_simple_settings(user)
+        self.configure_remove_settings(simple_settings=simple_settings,
+                                       input_file_templates=False)
+
     @classmethod
     def defaults(cls, config):
         cls._user_defaults(config)
@@ -455,7 +565,9 @@ class UserView(PrincipalMasterView):
         """
         Provide extra default configuration for the User master view.
         """
+        route_prefix = cls.get_route_prefix()
         permission_prefix = cls.get_permission_prefix()
+        instance_url_prefix = cls.get_instance_url_prefix()
         model_title = cls.get_model_title()
 
         # view/edit roles
@@ -464,6 +576,23 @@ class UserView(PrincipalMasterView):
         config.add_tailbone_permission(permission_prefix, '{}.edit_roles'.format(permission_prefix),
                                        "Edit the Roles to which a {} belongs".format(model_title))
 
+        # edit preferences for any user
+        config.add_tailbone_permission(permission_prefix,
+                                       '{}.preferences'.format(permission_prefix),
+                                       "Edit preferences for any {}".format(model_title))
+        config.add_route('{}.preferences'.format(route_prefix),
+                         '{}/preferences'.format(instance_url_prefix))
+        config.add_view(cls, attr='preferences',
+                        route_name='{}.preferences'.format(route_prefix),
+                        permission='{}.preferences'.format(permission_prefix))
+
+        # edit "my" preferences (for current user)
+        config.add_route('my.preferences',
+                         '/my/preferences')
+        config.add_view(cls, attr='my_preferences',
+                        route_name='my.preferences')
+
+
 # TODO: deprecate / remove this
 UsersView = UserView
 
@@ -472,7 +601,7 @@ class UserEventView(MasterView):
     """
     Master view for all user events
     """
-    model_class = model.UserEvent
+    model_class = UserEvent
     url_prefix = '/user-events'
     viewable = False
     creatable = False
@@ -488,10 +617,12 @@ class UserEventView(MasterView):
 
     def get_data(self, session=None):
         query = super(UserEventView, self).get_data(session=session)
+        model = self.model
         return query.join(model.User)
 
     def configure_grid(self, g):
         super(UserEventView, self).configure_grid(g)
+        model = self.model
         g.set_joiner('person', lambda q: q.outerjoin(model.Person))
         g.set_sorter('user', model.User.username)
         g.set_sorter('person', model.Person.display_name)
@@ -516,6 +647,15 @@ class UserEventView(MasterView):
 UserEventsView = UserEventView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    UserView = kwargs.get('UserView', base['UserView'])
     UserView.defaults(config)
+
+    UserEventView = kwargs.get('UserEventView', base['UserEventView'])
     UserEventView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
