@@ -180,5 +180,12 @@ class VendorView(MasterView):
         ]
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    VendorView = kwargs.get('VendorView', base['VendorView'])
     VendorView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
